Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon EC2 Image Builder.

Actions, resources, and condition keys for Amazon EC2 Image Builder - Service Authorization Reference

# Actions, resources, and condition keys for Amazon EC2 Image Builder

Amazon EC2 Image Builder (service prefix: `imagebuilder` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon EC2 Image Builder
- Resource types defined by Amazon EC2 Image Builder
- Condition keys for Amazon EC2 Image Builder

## Actions defined by Amazon EC2 Image Builder

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CancelImageCreation | Grants permission to cancel an image creation | Write | image* |  |
CreateComponent | Grants permission to create a new component | Write | component* |  | iam:CreateServiceLinkedRole imagebuilder:TagResource kms:Encrypt kms:GenerateDataKey kms:GenerateDataKeyWithoutPlaintext
kmsKey |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateContainerRecipe | Grants permission to create a new Container Recipe | Write | containerRecipe* |  | ecr:DescribeImages ecr:DescribeRepositories iam:CreateServiceLinkedRole imagebuilder:GetComponent imagebuilder:GetImage imagebuilder:TagResource kms:Encrypt kms:GenerateDataKey kms:GenerateDataKeyWithoutPlaintext
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateDistributionConfiguration | Grants permission to create a new distribution configuration | Write | distributionConfiguration* |  | iam:CreateServiceLinkedRole imagebuilder:TagResource
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateImage | Grants permission to create a new image | Write | image* |  | iam:CreateServiceLinkedRole imagebuilder:GetContainerRecipe imagebuilder:GetDistributionConfiguration imagebuilder:GetImageRecipe imagebuilder:GetInfrastructureConfiguration imagebuilder:TagResource
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateImagePipeline | Grants permission to create a new image pipeline | Write | imagePipeline* |  | iam:CreateServiceLinkedRole imagebuilder:GetContainerRecipe imagebuilder:GetImageRecipe imagebuilder:TagResource
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateImageRecipe | Grants permission to create a new Image Recipe | Write | imageRecipe* |  | ec2:DescribeImages iam:CreateServiceLinkedRole imagebuilder:GetComponent imagebuilder:GetImage imagebuilder:TagResource
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateInfrastructureConfiguration | Grants permission to create a new infrastructure configuration | Write | infrastructureConfiguration* |  | iam:CreateServiceLinkedRole iam:PassRole imagebuilder:TagResource sns:Publish
| aws:RequestTag/${TagKey} aws:TagKeys imagebuilder:CreatedResourceTagKeys imagebuilder:CreatedResourceTag/<key> imagebuilder:Ec2MetadataHttpTokens imagebuilder:StatusTopicArn |
DeleteComponent | Grants permission to delete a component | Write | component* |  |
DeleteContainerRecipe | Grants permission to delete a container recipe | Write | containerRecipe* |  |
DeleteDistributionConfiguration | Grants permission to delete a distribution configuration | Write | distributionConfiguration* |  |
DeleteImage | Grants permission to delete an image | Write | image* |  |
DeleteImagePipeline | Grants permission to delete an image pipeline | Write | imagePipeline* |  |
DeleteImageRecipe | Grants permission to delete an image recipe | Write | imageRecipe* |  |
DeleteInfrastructureConfiguration | Grants permission to delete an infrastructure configuration | Write | infrastructureConfiguration* |  |
GetComponent | Grants permission to view details about a component | Read | component* |  | kms:Decrypt
GetComponentPolicy | Grants permission to view the resource policy associated with a component | Read | component* |  |
GetContainerRecipe | Grants permission to view details about a container recipe | Read | containerRecipe* |  |
GetContainerRecipePolicy | Grants permission to view the resource policy associated with a container recipe | Read | containerRecipe* |  |
GetDistributionConfiguration | Grants permission to view details about a distribution configuration | Read | distributionConfiguration* |  |
GetImage | Grants permission to view details about an image | Read | image* |  |
| aws:ResourceTag/${TagKey} |
GetImagePipeline | Grants permission to view details about an image pipeline | Read | imagePipeline* |  |
GetImagePolicy | Grants permission to view the resource policy associated with an image | Read | image* |  |
GetImageRecipe | Grants permission to view details about an image recipe | Read | imageRecipe* |  |
GetImageRecipePolicy | Grants permission to view the resource policy associated with an image recipe | Read | imageRecipe* |  |
GetInfrastructureConfiguration | Grants permission to view details about an infrastructure configuration | Read | infrastructureConfiguration* |  |
GetWorkflowExecution | Grants permission to view details about a workflow execution | Read | workflowExecution* |  |
GetWorkflowStepExecution | Grants permission to view details about a workflow step execution | Read | workflowStepExecution* |  |
ImportComponent | Grants permission to import a new component | Write | component* |  | iam:CreateServiceLinkedRole imagebuilder:TagResource kms:Encrypt kms:GenerateDataKey kms:GenerateDataKeyWithoutPlaintext
kmsKey |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
ImportVmImage | Grants permission to import an image | Write | image* |  | ec2:DescribeImportImageTasks iam:CreateServiceLinkedRole
| aws:RequestTag/${TagKey} aws:TagKeys |
ListComponentBuildVersions | Grants permission to list the component build versions in your account | List | componentVersion* |  |
ListComponents | Grants permission to list the component versions owned by or shared with your account | List |  |  |
ListContainerRecipes | Grants permission to list the container recipes owned by or shared with your account | List |  |  |
ListDistributionConfigurations | Grants permission to list the distribution configurations in your account | List |  |  |
ListImageBuildVersions | Grants permission to list the image build versions in your account | List | imageVersion* |  |
ListImagePackages | Grants permission to return a list of packages installed on the specified image | List | image* |  |
| aws:ResourceTag/${TagKey} |
ListImagePipelineImages | Grants permission to return a list of images created by the specified pipeline | List | imagePipeline* |  |
ListImagePipelines | Grants permission to list the image pipelines in your account | List |  |  |
ListImageRecipes | Grants permission to list the image recipes owned by or shared with your account | List |  |  |
ListImageScanFindingAggregations | Grants permission to list aggregations on the image scan findings in your account | List | image |  |
imagePipeline |  |
ListImageScanFindings | Grants permission to list the image scan findings for the images in your account | List | image |  | inspector2:ListFindings
imagePipeline |  |
ListImages | Grants permission to list the image versions owned by or shared with your account | List |  |  |
ListInfrastructureConfigurations | Grants permission to list the infrastructure configurations in your account | List |  |  |
ListTagsForResource | Grants permission to list tags for an Image Builder resource | Read | component |  |
containerRecipe |  |
distributionConfiguration |  |
image |  |
imagePipeline |  |
imageRecipe |  |
infrastructureConfiguration |  |
| aws:ResourceTag/${TagKey} |
ListWorkflowExecutions | Grants permission to list workflow executions for the specified image | List | image* |  |
ListWorkflowStepExecutions | Grants permission to list workflow step executions for the specified workflow | List | workflowExecution* |  |
PutComponentPolicy | Grants permission to set the resource policy associated with a component | Permissions management | component* |  |
PutContainerRecipePolicy | Grants permission to set the resource policy associated with a container recipe | Permissions management | containerRecipe* |  |
PutImagePolicy | Grants permission to set the resource policy associated with an image | Permissions management | image* |  |
PutImageRecipePolicy | Grants permission to set the resource policy associated with an image recipe | Permissions management | imageRecipe* |  |
StartImagePipelineExecution | Grants permission to create a new image from a pipeline | Write | imagePipeline* |  | iam:CreateServiceLinkedRole imagebuilder:GetImagePipeline
TagResource | Grants permission to tag an Image Builder resource | Tagging | component |  |
containerRecipe |  |
distributionConfiguration |  |
image |  |
imagePipeline |  |
imageRecipe |  |
infrastructureConfiguration |  |
| aws:TagKeys aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} |
UntagResource | Grants permission to untag an Image Builder resource | Tagging | component |  |
containerRecipe |  |
distributionConfiguration |  |
image |  |
imagePipeline |  |
imageRecipe |  |
infrastructureConfiguration |  |
| aws:ResourceTag/${TagKey} aws:TagKeys |
UpdateDistributionConfiguration | Grants permission to update an existing distribution configuration | Write | distributionConfiguration* |  |
UpdateImagePipeline | Grants permission to update an existing image pipeline | Write | imagePipeline* |  |
UpdateInfrastructureConfiguration | Grants permission to update an existing infrastructure configuration | Write | infrastructureConfiguration* |  | iam:PassRole sns:Publish
| aws:ResourceTag/${TagKey} imagebuilder:CreatedResourceTagKeys imagebuilder:CreatedResourceTag/<key> imagebuilder:Ec2MetadataHttpTokens imagebuilder:StatusTopicArn |

## Resource types defined by Amazon EC2 Image Builder

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
component | `arn:$ { Partition}:imagebuilder:$ { Region}:$ { Account}:component/$ { ComponentName}/$ { ComponentVersion}/$ { ComponentBuildVersion}` | aws:ResourceTag/${TagKey}
componentVersion | `arn:$ { Partition}:imagebuilder:$ { Region}:$ { Account}:component/$ { ComponentName}/$ { ComponentVersion}` | aws:ResourceTag/${TagKey}
distributionConfiguration | `arn:$ { Partition}:imagebuilder:$ { Region}:$ { Account}:distribution-configuration/$ { DistributionConfigurationName}` | aws:ResourceTag/${TagKey}
image | `arn:$ { Partition}:imagebuilder:$ { Region}:$ { Account}:image/$ { ImageName}/$ { ImageVersion}/$ { ImageBuildVersion}` | aws:ResourceTag/${TagKey}
imageVersion | `arn:$ { Partition}:imagebuilder:$ { Region}:$ { Account}:image/$ { ImageName}/$ { ImageVersion}` | aws:ResourceTag/${TagKey}
imageRecipe | `arn:$ { Partition}:imagebuilder:$ { Region}:$ { Account}:image-recipe/$ { ImageRecipeName}/$ { ImageRecipeVersion}` | aws:ResourceTag/${TagKey}
containerRecipe | `arn:$ { Partition}:imagebuilder:$ { Region}:$ { Account}:container-recipe/$ { ContainerRecipeName}/$ { ContainerRecipeVersion}` | aws:ResourceTag/${TagKey}
imagePipeline | `arn:$ { Partition}:imagebuilder:$ { Region}:$ { Account}:image-pipeline/$ { ImagePipelineName}` | aws:ResourceTag/${TagKey}
infrastructureConfiguration | `arn:$ { Partition}:imagebuilder:$ { Region}:$ { Account}:infrastructure-configuration/$ { ResourceId}` | aws:ResourceTag/${TagKey}
kmsKey | `arn:$ { Partition}:kms:$ { Region}:$ { Account}:key/$ { KeyId}` |
workflowExecution | `arn:$ { Partition}:imagebuilder:$ { Region}:$ { Account}:workflow-execution/$ { WorkflowExecutionId}` |
workflowStepExecution | `arn:$ { Partition}:imagebuilder:$ { Region}:$ { Account}:workflow-step-execution/$ { WorkflowStepExecutionId}` |

## Condition keys for Amazon EC2 Image Builder

Amazon EC2 Image Builder defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters access by tag key-value pairs attached to the resource | String
aws:TagKeys | Filters access by the presence of tag keys in the request | ArrayOfString
imagebuilder:CreatedResourceTag/<key> | Filters access by the tag key-value pairs attached to the resource created by Image Builder | String
imagebuilder:CreatedResourceTagKeys | Filters access by the presence of tag keys in the request | ArrayOfString
imagebuilder:Ec2MetadataHttpTokens | Filters access by the EC2 Instance Metadata HTTP Token Requirement specified in the request | String
imagebuilder:StatusTopicArn | Filters access by the SNS Topic Arn in the request to which terminal state notifications will be published | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.